@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: cfgfile.h,v 1.14 1999/12/18 22:25:38 bazsi Exp $
+ * $Id: cfgfile.h,v 1.16 2000/02/13 16:24:01 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -45,12 +45,14 @@
         (backend object io_backend)
 	; global options
 	(chain_hostnames simple UINT32)
+	(keep_hostname simple UINT32)
 	(mark_freq simple UINT32)
 	(sync_freq simple UINT32)
 	(time_reopen simple UINT32)
 	(log_fifo_size simple UINT32)
 	(use_fqdn simple UINT32)
 	(use_dns simple UINT32)
+	(create_dirs simple UINT32)
 	(gc_busy_threshold simple UINT32)
 	(gc_idle_threshold simple UINT32)
 	; internal messages should come from this source
