@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: sources.c,v 1.23 2000/03/03 14:43:20 bazsi Exp $
+ * $Id: sources.c,v 1.23.2.1 2000/03/10 11:35:27 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -196,35 +196,44 @@ static struct ol_string *get_source_hostname(struct address_info *a, int usedns,
 static void do_add_source_name(struct log_handler *c, struct log_info *logmsg)
 {
 	CAST(log_source_group, self, c);
-	struct ol_string *name = get_source_hostname(logmsg->saddr, self->use_dns, self->use_fqdn);
+	struct ol_string *name;
+
 
 	if (!self->super.next) {
 		log_info_free(logmsg);
 		return;
 	}
 	logmsg->source = c;
-	if (self->chain_hostnames) {
-		if (logmsg->flags & LF_LOCAL) {
-			/* local */
-			ol_string_free(logmsg->host);
-			logmsg->host = c_format("%S@%fS", self->name, name);
+	if (!self->keep_hostname || !logmsg->host) {
+		name = get_source_hostname(logmsg->saddr, 
+					   self->use_dns, self->use_fqdn);
+		if (self->chain_hostnames) {
+			if (logmsg->flags & LF_LOCAL) {
+				/* local */
+				ol_string_free(logmsg->host);
+				logmsg->host = c_format("%S@%fS", 
+							self->name, name);
+			}
+			else if (!logmsg->host) {
+				/* remote && no hostname */
+				logmsg->host = c_format("%S/%fS", name, name);
+			} 
+			else {
+				/* everything else, append source hostname */
+				if (logmsg->host)
+					logmsg->host = 
+						c_format("%fS/%fS", 
+							 logmsg->host, name);
+				else
+					logmsg->host = 
+						c_format("%fS", name);
+			}
 		}
-		else if (!logmsg->host) {
-			/* remote && no hostname */
-			logmsg->host = c_format("%S/%fS", name, name);
-		} 
 		else {
-			/* everything else, append source hostname */
-			if (logmsg->host)
-				logmsg->host = c_format("%fS/%fS", logmsg->host, name);
-			else
-				logmsg->host = c_format("%fS", name);
+			ol_string_free(logmsg->host);
+			logmsg->host = c_format("%fS", name);
 		}
 	}
-	else {
-		ol_string_free(logmsg->host);
-		logmsg->host = c_format("%fS", name);
-	}
 	HANDLE_LOG(self->super.next, logmsg);
 }
 
@@ -238,6 +247,7 @@ static int do_init_group(struct log_handler *c, struct syslog_config *cfg, struc
 	self->chain_hostnames = cfg->chain_hostnames;
 	self->use_dns = cfg->use_dns;
 	self->use_fqdn = cfg->use_fqdn;
+	self->keep_hostname = cfg->keep_hostname;
 	res = 0;
 	for (drv = self->drivers; drv; drv = drv->next_driver) {
 		res = LOG_HANDLER_INIT(drv, cfg, persistent);
